@@ -2,6 +2,7 @@ from .peserta_didik_baru import PesertaDidikBaru
 from .peserta_didik_longitudinal import PesertaDidikLongitudinal
 from .registrasi_peserta_didik import RegistrasiPesertaDidik
 from .peserta_didik import PesertaDidik
+from .create_peserta_didik import CreatePesertaDidik
 
 from .base import BasePesertaDidik
 
@@ -11,5 +12,6 @@ __all__ = [
     "PesertaDidikLongitudinal",
     "RegistrasiPesertaDidik",
     "PesertaDidik",
+    "CreatePesertaDidik",
     "BasePesertaDidik",
 ]
