@@ -1,12 +1,11 @@
+import attr
 from datetime import datetime
 from typing import Optional
 
-import attr
-
 
 @attr.dataclass(frozen=True, slots=True)
 class JenisSarana:
-    jenis_sarana_id: str
+    jenis_sarana_id: int
     nama: str
     kelompok: Optional[str]
     perlu_penempatan: int
